@@ -10,6 +10,8 @@ has desc => ( is => 'lazy', isa => Str );
 # API settings
 has auth => ( is => 'ro', isa => Str, required => 1 );    # db, http or was uri
 
+has devel => ( is => 'ro', isa => Bool, default => 0 );
+
 # HTTP server settings
 has listen => ( is => 'ro', isa => Str, required => 1 );
 has keepalive_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 60 );
@@ -87,10 +89,6 @@ sub _build_http_server ($self) {
 
 # TODO init appliacation
 around run => sub ( $orig, $self, $cb = undef ) {
-
-    # scan router classes
-    $self->router->map;
-
     my $cv = AE::cv sub {
         $self->$orig(
             sub {
@@ -107,8 +105,18 @@ around run => sub ( $orig, $self, $cb = undef ) {
         return;
     };
 
+    # init api
+    $self->api->init_api if $self->api;
+
+    # scan router classes
+    print 'Scanning HTTP controllers ... ';
+    $self->router->map;
+    say 'done';
+
     if ( $self->api ) {
-        $self->api->init(
+
+        # connect api
+        $self->api->connect_api(
             sub ($status) {
                 exit if !$status;
 
